@@ -91,94 +91,6 @@ def ignore_feature(feature):
         "start-powered-off",
         "tcg-cpuid",
         "vmware-cpuid-freq",
-        "vmx-activity-hlt",
-        "vmx-activity-shutdown",
-        "vmx-activity-wait-sipi",
-        "vmx-apicv-register",
-        "vmx-apicv-vid",
-        "vmx-apicv-x2apic",
-        "vmx-apicv-xapic",
-        "vmx-cr3-load-noexit",
-        "vmx-cr3-store-noexit",
-        "vmx-cr8-load-exit",
-        "vmx-cr8-store-exit",
-        "vmx-desc-exit",
-        "vmx-encls-exit",
-        "vmx-entry-ia32e-mode",
-        "vmx-entry-load-bndcfgs",
-        "vmx-entry-load-efer",
-        "vmx-entry-load-pat",
-        "vmx-entry-load-perf-global-ctrl",
-        "vmx-entry-load-pkrs",
-        "vmx-entry-load-rtit-ctl",
-        "vmx-entry-noload-debugctl",
-        "vmx-ept",
-        "vmx-ept-1gb",
-        "vmx-ept-2mb",
-        "vmx-ept-advanced-exitinfo",
-        "vmx-ept-execonly",
-        "vmx-eptad",
-        "vmx-eptp-switching",
-        "vmx-exit-ack-intr",
-        "vmx-exit-clear-bndcfgs",
-        "vmx-exit-clear-rtit-ctl",
-        "vmx-exit-load-efer",
-        "vmx-exit-load-pat",
-        "vmx-exit-load-perf-global-ctrl",
-        "vmx-exit-load-pkrs",
-        "vmx-exit-nosave-debugctl",
-        "vmx-exit-save-efer",
-        "vmx-exit-save-pat",
-        "vmx-exit-save-preemption-timer",
-        "vmx-flexpriority",
-        "vmx-hlt-exit",
-        "vmx-ins-outs",
-        "vmx-intr-exit",
-        "vmx-invept",
-        "vmx-invept-all-context",
-        "vmx-invept-single-context",
-        "vmx-invept-single-context-noglobals",
-        "vmx-invlpg-exit",
-        "vmx-invpcid-exit",
-        "vmx-invvpid",
-        "vmx-invvpid-all-context",
-        "vmx-invvpid-single-addr",
-        "vmx-io-bitmap",
-        "vmx-io-exit",
-        "vmx-monitor-exit",
-        "vmx-movdr-exit",
-        "vmx-msr-bitmap",
-        "vmx-mtf",
-        "vmx-mwait-exit",
-        "vmx-nmi-exit",
-        "vmx-page-walk-4",
-        "vmx-page-walk-5",
-        "vmx-pause-exit",
-        "vmx-ple",
-        "vmx-pml",
-        "vmx-posted-intr",
-        "vmx-preemption-timer",
-        "vmx-rdpmc-exit",
-        "vmx-rdrand-exit",
-        "vmx-rdseed-exit",
-        "vmx-rdtsc-exit",
-        "vmx-rdtscp-exit",
-        "vmx-secondary-ctls",
-        "vmx-shadow-vmcs",
-        "vmx-store-lma",
-        "vmx-true-ctls",
-        "vmx-tsc-offset",
-        "vmx-tsc-scaling",
-        "vmx-unrestricted-guest",
-        "vmx-vintr-pending",
-        "vmx-vmfunc",
-        "vmx-vmwrite-vmexit-fields",
-        "vmx-vnmi",
-        "vmx-vnmi-pending",
-        "vmx-vpid",
-        "vmx-wbinvd-exit",
-        "vmx-xsaves",
-        "vmx-zero-len-inject",
         "xen-vapic",
     ]
 
@@ -187,7 +99,7 @@ def ignore_feature(feature):
 
     name = feature["name"]
 
-    if name.startswith("x-"):
+    if name.startswith("x-") or name.startswith("vmx-"):
         return True
 
     if name in ignored_features:
