@@ -1213,7 +1213,7 @@ mymain(void)
 
     TEST_IMAGE_CREATE("network-gluster-qcow2", NULL);
     TEST_IMAGE_CREATE("network-rbd-qcow2", NULL);
-    TEST_IMAGE_CREATE("network-ssh-qcow2-invalid", NULL);
+    TEST_IMAGE_CREATE("network-ssh-qcow2", NULL);
 
 #define TEST_BITMAP_DETECT(testname) \
     do { \
