@@ -28,6 +28,7 @@
 # define TEST_TPM_ENV_VAR "VIR_TEST_MOCK_FAKE_TPM_VERSION"
 # define TPM_VER_1_2 "1.2"
 # define TPM_VER_2_0 "2.0"
+# define TEST_NBDKIT_PATH "/fakebindir/nbdkit"
 
 enum {
     GIC_NONE = 0,
@@ -49,6 +50,8 @@ typedef enum {
     ARG_CAPS_VARIANT,
     ARG_CAPS_HOST_CPU_MODEL,
     ARG_FD_GROUP, /* name, nfds, fd[0], ... fd[n-1] */
+    ARG_VDPA_FD, /* vdpadev, fd */
+    ARG_NBDKIT_CAPS,
     ARG_END,
 } testQemuInfoArgName;
 
@@ -57,9 +60,8 @@ typedef enum {
     FLAG_EXPECT_PARSE_ERROR = 1 << 1,
     FLAG_FIPS_HOST          = 1 << 2, /* simulate host with FIPS mode enabled */
     FLAG_REAL_CAPS          = 1 << 3,
-    FLAG_SKIP_LEGACY_CPUS   = 1 << 4,
-    FLAG_SLIRP_HELPER       = 1 << 5,
-    FLAG_SKIP_CONFIG_ACTIVE = 1 << 6, /* Skip 'active' config test in qemuxml2xmltest */
+    FLAG_SLIRP_HELPER       = 1 << 4,
+    FLAG_SKIP_CONFIG_ACTIVE = 1 << 5, /* Skip 'active' config test in qemuxml2xmltest */
 } testQemuInfoFlags;
 
 struct testQemuConf {
@@ -80,12 +82,14 @@ struct testQemuArgs {
     bool newargs;
     virBitmap *fakeCapsAdd;
     virBitmap *fakeCapsDel;
+    virBitmap *fakeNbdkitCaps;
     char *capsver;
     char *capsarch;
     const char *capsvariant;
     qemuTestCPUDef capsHostCPUModel;
     int gic;
     GHashTable *fds;
+    GHashTable *vdpafds;
     bool invalidarg;
 };
 
@@ -95,6 +99,7 @@ struct testQemuInfo {
     char *outfile;
     char *errfile;
     virQEMUCaps *qemuCaps;
+    qemuNbdkitCaps *nbdkitCaps;
     const char *migrateFrom;
     int migrateFd;
     unsigned int flags;
@@ -106,7 +111,6 @@ struct testQemuInfo {
     struct testQemuConf *conf;
 };
 
-virCaps *testQemuCapsInit(void);
 virDomainXMLOption *testQemuXMLConfInit(void);
 
 
